@@ -21,15 +21,12 @@ import org.apache.seatunnel.flink.BaseFlinkSink;
 import org.apache.seatunnel.flink.FlinkEnvironment;
 
 import org.apache.flink.api.java.DataSet;
-import org.apache.flink.api.java.operators.DataSink;
-
-import javax.annotation.Nullable;
+import org.apache.flink.types.Row;
 
 /**
  * a FlinkBatchSink plugin will write data to other system using Flink DataSet API.
  */
-public interface FlinkBatchSink<IN, OUT> extends BaseFlinkSink {
+public interface FlinkBatchSink extends BaseFlinkSink {
 
-    @Nullable
-    DataSink<OUT> outputBatch(FlinkEnvironment env, DataSet<IN> inDataSet);
+    void outputBatch(FlinkEnvironment env, DataSet<Row> inDataSet);
 }
