@@ -21,16 +21,13 @@ import org.apache.seatunnel.flink.BaseFlinkSink;
 import org.apache.seatunnel.flink.FlinkEnvironment;
 
 import org.apache.flink.streaming.api.datastream.DataStream;
-import org.apache.flink.streaming.api.datastream.DataStreamSink;
-
-import javax.annotation.Nullable;
+import org.apache.flink.types.Row;
 
 /**
  * a FlinkStreamSink plugin will write data to other system using Flink DataStream API.
  */
-public interface FlinkStreamSink<IN, OUT> extends BaseFlinkSink {
+public interface FlinkStreamSink extends BaseFlinkSink {
 
-    @Nullable
-    DataStreamSink<OUT> outputStream(FlinkEnvironment env, DataStream<IN> dataStream);
+    void outputStream(FlinkEnvironment env, DataStream<Row> dataStream);
 
 }
