@@ -25,7 +25,7 @@ import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;
 /**
  * a base interface indicates a source plugin running on Spark.
  */
-public abstract class BaseSparkSource<T> implements BaseSource<SparkEnvironment> {
+public abstract class BaseSparkSource<OUT> implements BaseSource<SparkEnvironment> {
 
     protected Config config = ConfigFactory.empty();
 
@@ -39,5 +39,5 @@ public abstract class BaseSparkSource<T> implements BaseSource<SparkEnvironment>
         return this.config;
     }
 
-    public abstract T getData(SparkEnvironment env);
+    public abstract OUT getData(SparkEnvironment env);
 }
