@@ -111,14 +111,11 @@ final class ConfigParser {
 
                 Path path = pathStack.peekFirst();
 
-                if (path != null
-                    && ("input".equals(path.first())
-                    || "filter".equals(path.first())
-                    || "output".equals(path.first())
-                    || "source".equals(path.first())
+                if (path != null && !ConfigSyntax.JSON.equals(flavor)
+                    && ("source".equals(path.first())
                     || "transform".equals(path.first())
                     || "sink".equals(path.first()))) {
-                    v = parseObjectForWaterdrop((ConfigNodeObject) n);
+                    v = parseObjectForSeatunnel((ConfigNodeObject) n);
                 } else {
                     v = parseObject((ConfigNodeObject) n);
                 }
@@ -236,7 +233,7 @@ final class ConfigParser {
             }
         }
 
-        private SimpleConfigList parseObjectForWaterdrop(ConfigNodeObject n) {
+        private SimpleConfigList parseObjectForSeatunnel(ConfigNodeObject n) {
 
             Map<String, AbstractConfigValue> values = new LinkedHashMap<>();
             List<AbstractConfigValue> valuesList = new ArrayList<>();
