@@ -31,5 +31,6 @@ class Sql extends BaseSparkTransform {
     checkAllExists(config, "sql")
   }
 
-  override def prepare(env: SparkEnvironment): Unit = {}
+  override def getPluginName: String = "sql"
+
 }
